@@ -37,11 +37,12 @@
 #ifndef URDF_INTERFACE_COLOR_H
 #define URDF_INTERFACE_COLOR_H
 
+#include <stdexcept>
 #include <string>
 #include <vector>
 #include <math.h>
-#include <boost/algorithm/string.hpp>
-#include <boost/lexical_cast.hpp>
+
+#include <urdf_model/utils.h>
 
 namespace urdf
 {
@@ -65,18 +66,20 @@ public:
     this->clear();
     std::vector<std::string> pieces;
     std::vector<float> rgba;
-    boost::split( pieces, vector_str, boost::is_any_of(" "));
+    urdf::split_string( pieces, vector_str, " ");
     for (unsigned int i = 0; i < pieces.size(); ++i)
     {
       if (!pieces[i].empty())
       {
         try
         {
-          rgba.push_back(boost::lexical_cast<float>(pieces[i].c_str()));
+          double piece = strToDouble(pieces[i].c_str());
+          if ((piece < 0) || (piece > 1))
+            throw ParseError("Component [" + pieces[i] + "] is outside the valid range for colors [0, 1]");
+          rgba.push_back(static_cast<float>(piece));
         }
-        catch (boost::bad_lexical_cast &/*e*/)
-        {
-          return false;
+        catch (std::runtime_error &/*e*/) {
+          throw ParseError("Unable to parse component [" + pieces[i] + "] to a double (while parsing a color value)");
         }
       }
     }
